function varargout = procenta(varargin)
% PROCENTA MATLAB code for procenta.fig
%      PROCENTA, by itself, creates a new PROCENTA or raises the existing
%      singleton*.
%
%      H = PROCENTA returns the handle to a new PROCENTA or the handle to
%      the existing singleton*.
%
%      PROCENTA('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in PROCENTA.M with the given input arguments.
%
%      PROCENTA('Property','Value',...) creates a new PROCENTA or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before procenta_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to procenta_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help procenta

% Last Modified by GUIDE v2.5 31-Dec-2018 21:39:01

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @procenta_OpeningFcn, ...
                   'gui_OutputFcn',  @procenta_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before procenta is made visible.
function procenta_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to procenta (see VARARGIN)

% Choose default command line output for procenta
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes procenta wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = procenta_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;



function cislo_x_Callback(hObject, eventdata, handles)
% hObject    handle to cislo_x (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of cislo_x as text
%        str2double(get(hObject,'String')) returns contents of cislo_x as a double


% --- Executes during object creation, after setting all properties.
function cislo_x_CreateFcn(hObject, eventdata, handles)
% hObject    handle to cislo_x (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
c=0;
f=1;
b=3;
d=c+b;
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function cislo_y_Callback(hObject, eventdata, handles)
% hObject    handle to cislo_y (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of cislo_y as text
%        str2double(get(hObject,'String')) returns contents of cislo_y as a double


% --- Executes during object creation, after setting all properties.
function cislo_y_CreateFcn(hObject, eventdata, handles)
% hObject    handle to cislo_y (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end




% --- Executes on button press in spocitej.
function spocitej_Callback(hObject, eventdata, handles)
% hObject    handle to spocitej (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
x=str2num(get(handles.cislo_x,'String'));
y=str2num(get(handles.cislo_y,'String'));
z=((x/100)*y);
set(handles.vysledek,'String',z);
